==> qtjambi-sensors-6.6.0-sources.jar: io/qt/sensors/QRotationSensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qrotationsensor.html">QRotationSensor</a></code></p>
 */
public class QRotationSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRotationSensor.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qrotationsensor.html#hasZ-prop">QRotationSensor::<wbr>hasZChanged(bool)</a></code></p>
     */
    @QtPropertyNotify(name="hasZ")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Boolean> hasZChanged = new Signal1<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qrotationsensor.html#QRotationSensor">QRotationSensor::<wbr>QRotationSensor(QObject*)</a></code></p>
     */
    public QRotationSensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRotationSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qrotationsensor.html#hasZ-prop">QRotationSensor::<wbr>hasZ()const</a></code></p>
     */
    @QtPropertyReader(name="hasZ")
    @QtUninvokable
    public final boolean hasZ(){
        return hasZ_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasZ_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::<wbr>reading()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QRotationReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QRotationReading reading_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qrotationsensor.html#setHasZ">QRotationSensor::<wbr>setHasZ(bool)</a></code></p>
     */
    @QtUninvokable
    public final void setHasZ(boolean hasZ){
        setHasZ_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), hasZ);
    }
    
    @QtUninvokable
    private native void setHasZ_native_bool(long __this__nativeId, boolean hasZ);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QRotationSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QRotationSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QRotationSensor instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRotationSensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRotationSensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #hasZ()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getHasZ() {
        return hasZ();
    }
}

==> qtjambi-sensors-6.6.2-sources.jar: io/qt/sensors/QRotationSensor.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Convenience wrapper around QSensor</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qrotationsensor.html">QRotationSensor</a></code></p>
 */
public class QRotationSensor extends io.qt.sensors.QSensor
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRotationSensor.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qrotationsensor.html#hasZ-prop">QRotationSensor::<wbr/>hasZChanged(bool)</a></code></p>
     */
    @QtPropertyNotify(name="hasZ")
    public final @NonNull Signal1<java.lang.@QtPrimitiveType@NonNull Boolean> hasZChanged = new Signal1<>();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qrotationsensor.html#QRotationSensor">QRotationSensor::<wbr/>QRotationSensor(QObject*)</a></code></p>
     */
    public QRotationSensor(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRotationSensor instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qrotationsensor.html#hasZ-prop">QRotationSensor::<wbr/>hasZ()const</a></code></p>
     */
    @QtPropertyReader(name="hasZ")
    @QtUninvokable
    public final boolean hasZ(){
        return hasZ_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasZ_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qsensor.html#reading-prop">QSensor::<wbr/>reading()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.sensors.@Nullable QRotationReading reading(){
        return reading_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.sensors.QRotationReading reading_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qrotationsensor.html#setHasZ">QRotationSensor::<wbr/>setHasZ(bool)</a></code></p>
     */
    @QtUninvokable
    public final void setHasZ(boolean hasZ){
        setHasZ_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), hasZ);
    }
    
    @QtUninvokable
    private native void setHasZ_native_bool(long __this__nativeId, boolean hasZ);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QRotationSensor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QRotationSensor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QRotationSensor instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRotationSensor(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QRotationSensor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #hasZ()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getHasZ() {
        return hasZ();
    }
}
